@@ -17,6 +17,17 @@ from searchlight.elasticsearch.plugins.designate import notification_handlers
 
 
 class ZoneIndex(designate.DesignateBase):
+    NotificationHandlerCls = notification_handlers.ZoneHandler
+
+    def get_notification_handler(self):
+        """Override because the zone handler needs a handle to recordset
+        indexer (for initial recordset indexing).
+        """
+        return self.NotificationHandlerCls(
+            self.index_helper,
+            self.options,
+            recordset_helper=self.child_plugins[0].index_helper)
+
     @classmethod
     def get_document_type(cls):
         return "OS::Designate::Zone"
@@ -88,21 +99,3 @@ class ZoneIndex(designate.DesignateBase):
         if not obj['updated_at'] and obj['created_at']:
             obj['updated_at'] = obj['created_at']
         return obj
-
-    @classmethod
-    def get_notification_exchanges(cls):
-        return ['designate']
-
-    def get_notification_handler(self):
-        return notification_handlers.DomainHandler(
-            self.engine,
-            self.get_index_name(),
-            self.get_document_type()
-        )
-
-    def get_notification_supported_events(self):
-        return [
-            "dns.domain.create",
-            "dns.domain.update",
-            "dns.domain.delete",
-            "dns.domain.exists"]
